# Author: Acer Zhang
# Datetime:2021/9/29 
# Copyright belongs to the author.
# Please indicate the source for reprinting.
from qwebsite.submethod.github import QWebSiteOptGUI

QWebSiteOptGUI().run()
